@@ -72,10 +72,6 @@ typedef enum {
         SLEEP_KEY,
         SUSPEND_KEY,
         HIBERNATE_KEY,
-        POWER_KEY_NO_DIALOG,
-        SLEEP_KEY_NO_DIALOG,
-        SUSPEND_KEY_NO_DIALOG,
-        HIBERNATE_KEY_NO_DIALOG,
         SCREEN_BRIGHTNESS_UP_KEY,
         SCREEN_BRIGHTNESS_DOWN_KEY,
         KEYBOARD_BRIGHTNESS_UP_KEY,
